==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCameraImageCaptureControl_shell.h <==
#ifndef QCAMERAIMAGECAPTURECONTROL_SHELL_H
#define QCAMERAIMAGECAPTURECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameraimagecapturecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtMultimedia/qcameraimagecapture.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtJambi/RegistryAPI>


class QCameraImageCaptureControl_shell : public QCameraImageCaptureControl, public QtJambiShellInterface
{
public:
    QCameraImageCaptureControl_shell(QObject* parent0 = nullptr);
    ~QCameraImageCaptureControl_shell() override;

    void cancelCapture() override;
    int capture(const QString& fileName0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QCameraImageCapture::DriveMode driveMode() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isReadyForCapture() const override;
    void setDriveMode(QCameraImageCapture::DriveMode mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraImageCaptureControl_access : public QCameraImageCaptureControl
{
    void __qt_cancelCapture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_capture_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0);
    jint __qt_driveMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isReadyForCapture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setDriveMode_QCameraImageCapture_DriveMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAIMAGECAPTURECONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCameraImageCaptureControl_shell.h <==
#ifndef QCAMERAIMAGECAPTURECONTROL_SHELL_H
#define QCAMERAIMAGECAPTURECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameraimagecapturecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtMultimedia/qcameraimagecapture.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtJambi/RegistryAPI>


class QCameraImageCaptureControl_shell : public QCameraImageCaptureControl, public QtJambiShellInterface
{
public:
    QCameraImageCaptureControl_shell(QObject* parent0 = nullptr);
    ~QCameraImageCaptureControl_shell() override;

    void cancelCapture() override;
    int capture(const QString& fileName0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QCameraImageCapture::DriveMode driveMode() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isReadyForCapture() const override;
    void setDriveMode(QCameraImageCapture::DriveMode mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraImageCaptureControl_access : public QCameraImageCaptureControl
{
    void __qt_cancelCapture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_capture_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0);
    jint __qt_driveMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isReadyForCapture_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setDriveMode_QCameraImageCapture_DriveMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAIMAGECAPTURECONTROL_SHELL_H
